package com.ic.modules.auth.controller;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataIntegrityViolationException;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.ic.annotation.AuditLogs;
import com.ic.constant.LeaderCalcConfig;
import com.ic.constant.StatusCode;
import com.ic.exception.ResourceNotFoundException;
import com.ic.modules.auth.model.DTSlabsMapping;
import com.ic.modules.auth.model.L1slabsMapping;
import com.ic.modules.auth.payload.DTslabsDto;
import com.ic.modules.auth.payload.L1slabsDto;
import com.ic.modules.auth.payload.request.ApiResponse;
import com.ic.modules.auth.service.DTslabsService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController 
@RequestMapping("/api/v1")
@Api(description = "DT Slabs maping management API")


public class DTslabsMappingController {
	
	@Autowired
	DTslabsService dtslabsService;
	
	LeaderCalcConfig LeaderCalcConfig;
    @PostMapping("/dtslabsmapping/get")
    @ApiOperation("Get all dtslabs mapping list")
    @AuditLogs(isRequest = true, isResponse = true,service="Get dtslabs")
    public ResponseEntity<?> getAllDtslabsMappings( ){   // neel gosrani 27-05-2020 Activation DT CR to fetch data from service and DB
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "dt slabs List", dtslabsService.findAll().stream().map(DtSlabsMapping -> new DTslabsDto(DtSlabsMapping))), HttpStatus.OK);
    }

    @PostMapping("/dtslabsmapping/create")
    @ApiOperation("Create dtsalbsmapping")
    @AuditLogs(isRequest = true, isResponse = true,service="Create dtslabsmapping")
    public ResponseEntity<?> createdtslabsmapping(@RequestBody DTslabsDto dtslabsMapping) {  // neel gosrani 27-05-2020 Activation DT CR to store data from service and DB
    	
    	DTSlabsMapping l1 = null;
    	try {
    		l1 =  dtslabsService.save(dtslabsMapping,true);

    	}catch(ResourceNotFoundException e) {
    		e.printStackTrace();
    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "dtmapping Not found", l1.getId()), HttpStatus.NOT_FOUND);
    	}catch(Exception e) {
    		e.printStackTrace();
    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "dtmapping creation failed", l1.getId()), HttpStatus.BAD_REQUEST);
    	}
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "dtmapping added successfully", new DTslabsDto(l1)), HttpStatus.OK);
    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
    }
    
    @PostMapping("/dtslabsmapping/update")
    @ApiOperation("update dtslabsmapping")
    @AuditLogs(isRequest = true, isResponse = true,service="Create dtslabsmapping")
    public ResponseEntity<?> updatedtslabsmapping(@RequestBody DTslabsDto DtSlabsMapping) {  // neel gosrani 27-05-2020 Activation DT CR to update data from service and DB
    
    	DTSlabsMapping l1 = null;
    	try {
    		l1 =  dtslabsService.save(DtSlabsMapping,false);

    	}catch(ResourceNotFoundException e) {
    		e.printStackTrace();
    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "dtmapping Not found", l1.getId()), HttpStatus.NOT_FOUND);
    	}catch(Exception e) {
    		e.printStackTrace();
    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "dtmapping creation failed", l1.getId()), HttpStatus.BAD_REQUEST);
    	}
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "dtmapping added successfully", new DTslabsDto(l1)), HttpStatus.OK);
    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
    }
    
}
