package com.ic.modules.auth.controller;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataIntegrityViolationException;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.ic.annotation.AuditLogs;
import com.ic.constant.LeaderCalcConfig;
import com.ic.constant.StatusCode;
import com.ic.exception.ResourceNotFoundException;
import com.ic.modules.auth.payload.fycDto;
import com.ic.modules.auth.payload.mpbDto;
import com.ic.modules.auth.payload.request.ApiResponse;
import com.ic.modules.auth.service.FycMappingService;
import com.ic.modules.auth.service.MpbMappingService;
import com.ic.modules.auth.model.FycMapping;
import com.ic.modules.auth.model.MpbMapping;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController 
@RequestMapping("/api/v1")
@Api(description = "MPB maping management API")

public class MpbMappingController {
	
	 @Autowired
	  MpbMappingService mpbMappingService;
	 
	 LeaderCalcConfig LeaderCalcConfig;
	    @PostMapping("/mpbmapping/get")
	    @ApiOperation("Get all mpb mapping list")
	    @AuditLogs(isRequest = true, isResponse = true,service="Get mpb")
	    
	    //Neel – 20-Apr-2020 – Tata - mpb mapping – Added function for storing all data of mpb mapping  table
	    public ResponseEntity<?> getAllMpbMappings( ){
	    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "Mpb List", mpbMappingService.findAll().stream().map(MpbMapping -> new mpbDto(MpbMapping))), HttpStatus.OK);
	    }
	    @PostMapping("/mpbmapping/create")
	    @ApiOperation("Create mpbmapping")
	    @AuditLogs(isRequest = true, isResponse = true,service="Create mpbmapping")
	    //Neel – 20-Apr-2020 – Tata - mdb mapping – Added function for storing all data of mdb mapping  table
	    public ResponseEntity<?> createMpbmapping(@RequestBody mpbDto mpbMapping) {
	    	// System.out.println("in mpb contrroler");
	    	// System.out.println("in mpbmapping");
	    	MpbMapping mpb = null;
	    	try {
	    		mpb =  mpbMappingService.save(mpbMapping,true);

	    	}catch(ResourceNotFoundException e) {
	    		e.printStackTrace();
	    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "mpbmapping Not found", mpb.getId()), HttpStatus.NOT_FOUND);
	    	}catch(Exception e) {
	    		e.printStackTrace();
	    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "mpbmapping creation failed", mpb.getId()), HttpStatus.BAD_REQUEST);
	    	}
	    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "mpb mapping added successfully", new mpbDto(mpb)), HttpStatus.OK);
	    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
	    }
	    @PostMapping("/mpbmapping/update")
	    @ApiOperation("update mpbmapping")
	    @AuditLogs(isRequest = true, isResponse = true,service="update mpbmapping")
	    public ResponseEntity<?> updateMpbmapping(@RequestBody mpbDto mpbMapping) {
	    	// System.out.println("in mpb contrroler");
	    	// System.out.println("in mpbmapping");
	    	MpbMapping mpb = null;
	    	try {
	    		mpb =  mpbMappingService.save(mpbMapping,false);

	    	}catch(ResourceNotFoundException e) {
	    		e.printStackTrace();
	    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "mpbmapping Not found", mpb.getId()), HttpStatus.NOT_FOUND);
	    	}catch(Exception e) {
	    		e.printStackTrace();
	    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "mpbmapping creation failed", mpb.getId()), HttpStatus.BAD_REQUEST);
	    	}
	    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "mpb mapping updated successfully", new mpbDto(mpb)), HttpStatus.OK);
	    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
	    }
	    

}
