package com.ic.modules.auth.controller;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataIntegrityViolationException;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ic.annotation.AuditLogs;
import com.ic.constant.DBConfig;
import com.ic.constant.StatusCode;
import com.ic.exception.ResourceNotFoundException;
import com.ic.modules.auth.model.Templates;
import com.ic.modules.auth.payload.TemplatesDto;
import com.ic.modules.auth.payload.request.ApiResponse;
import com.ic.modules.auth.service.TemplatesService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

@RestController 
@RequestMapping("/api/v1")
@Api(description = "Templates management API")
public class TemplatesController {
  
    @Autowired
    TemplatesService templatesService;
 
    @Autowired
    DBConfig DBConfig;
    @PostMapping("/templates/get")
    @ApiOperation("Get all templates list")
    @AuditLogs(isRequest = true, isResponse = true,service="Get Template")
    public ResponseEntity<?> getAllTemplates( ){
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "Templates List", templatesService.findAll().stream().map(templates -> new TemplatesDto(templates))), HttpStatus.OK);
    }
 
    @PostMapping("/templates/refresh")
    @ApiOperation("to Refresh all templates list")
    @AuditLogs(isRequest = true, isResponse = true,service="Refresh Template")
    public ResponseEntity<?> refreshTemplates( ){
    	DBConfig.refreshConfig();
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "Templates has been refreshed", null), HttpStatus.OK);
    }
     
    @PostMapping("/templates/create")
    @ApiOperation("Create templates")
    @AuditLogs(isRequest = true, isResponse = true,service="Create Template")
    public ResponseEntity<?> createTemplates(@RequestBody TemplatesDto templates) {
    	Templates template = null;
    	try {
	    	template =  templatesService.save(templates,true);

    	}catch(ResourceNotFoundException e) {
    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_NOT_FOUND, true, "Templates Not found", templates.getKey()), HttpStatus.NOT_FOUND);
    	}catch(Exception e) {
    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "Templates creation failed", templates.getKey()), HttpStatus.BAD_REQUEST);
    	}
    	return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "Templates added successfully", new TemplatesDto(template)), HttpStatus.OK);
    	//return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
    }

    @PostMapping("/templates/update")
    @ApiOperation("Update templates")
    @AuditLogs(isRequest = true, isResponse = true,service="Update Template")
    public ResponseEntity<?> updateTemplates(@RequestBody TemplatesDto templates) {
    	try {
    		Templates newUSer =  templatesService.save(templates,false);
    		return new ResponseEntity(new ApiResponse(HttpStatus.OK.value(), true, "Templates updated successfully", new TemplatesDto(newUSer)), HttpStatus.OK);
    	}catch(DataIntegrityViolationException e) {
    		return new ResponseEntity(new ApiResponse(StatusCode.RESOURCE_EXIST, true, "Templates data already exist", null), HttpStatus.ALREADY_REPORTED);
    	}catch(ResourceNotFoundException e) {
    		return new ResponseEntity(new ApiResponse(StatusCode.INVALID_USER, true, "Templates record not found", null), HttpStatus.NOT_FOUND);
    	}catch(Exception e) {
    		return new ResponseEntity(new ApiResponse(StatusCode.UNEXPECTED_ERROR, true, "Templates updation failed", null), HttpStatus.BAD_REQUEST);
    	}
    	//return new ResponseEntity(new ApiResponse(StatusCode.DEPENDANCY_EXIST, true, "USER_Already_Exist", null), HttpStatus.NOT_FOUND);
    }

}
